@@ -8,7 +8,7 @@ mod queue;
 /**
  * MIT License
  *
- * termscp - Copyright (c) 2021 Christian Visintin
+ * termusic - Copyright (c) 2021 Larry Hao
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -33,6 +33,7 @@ mod queue;
 // mod config;
 mod update;
 mod view;
+mod youtube_options;
 
 // Locals
 // use super::super::super::player::Player;
@@ -44,6 +45,7 @@ use crate::ui::activity::tageditor::TagEditorActivity;
 use std::str::FromStr;
 // Ext
 use crate::config::TermusicConfig;
+use crate::invidious::YoutubeVideo;
 use crossterm::terminal::{disable_raw_mode, enable_raw_mode};
 use log::error;
 use std::path::{Path, PathBuf};
@@ -58,6 +60,7 @@ use tuirealm::{Payload, Value, View};
 const COMPONENT_LABEL_HELP: &str = "LABEL_HELP";
 const COMPONENT_PARAGRAPH_LYRIC: &str = "PARAGRAPH_LYRIC";
 const COMPONENT_SCROLLTABLE: &str = "SCROLLTABLE";
+const COMPONENT_SCROLLTABLE_YOUTUBE: &str = "SCROLLTABLE_YOUTUBE";
 const COMPONENT_TREEVIEW: &str = "TREEVIEW";
 const COMPONENT_PROGRESS: &str = "PROGRESS";
 const COMPONENT_TEXT_HELP: &str = "TEXT_HELP";
@@ -88,7 +91,9 @@ pub struct MainActivity {
     receiver: Receiver<TransferState>,
     yanked_node_id: Option<String>,
     config: TermusicConfig,
-    // download_spin: i32,
+    youtube_options: Vec<YoutubeVideo>,
+    youtube_options_index: u32,
+    youtube_options_url: String,
 }
 
 // TransferState is used to describe the status of download
@@ -125,7 +130,9 @@ impl Default for MainActivity {
             receiver: rx,
             yanked_node_id: None,
             config: TermusicConfig::default(),
-            // download_spin: 0,
+            youtube_options: Vec::new(),
+            youtube_options_index: 1,
+            youtube_options_url: "".to_string(),
         }
     }
 }
@@ -154,7 +161,7 @@ impl MainActivity {
             }
             Some(Status::Running) => {}
             Some(Status::Paused) => {}
-            None => {}
+            None => self.status = Some(Status::Stopped),
         };
     }
 
@@ -192,6 +199,7 @@ impl MainActivity {
         loop {
             // Draw activity
             tageditor.on_draw();
+            tageditor.update_download_progress();
             // Check if activity has terminated
             if let Some(ExitReason::Quit) = tageditor.will_umount() {
                 // info!("SetupActivity terminated due to 'Quit'");
@@ -236,10 +244,6 @@ impl Activity for MainActivity {
             error!("Failed to save queue: {}", err);
         }
         self.status = Some(Status::Stopped);
-        // // Verify error state from context
-        // if let Some(err) = self.context.as_mut().unwrap().get_error() {
-        //     self.mount_error(err.as_str());
-        // }
     }
 
     /// ### on_draw
