@@ -1,12 +1,7 @@
-//! ## SetupActivity
-//!
-//! `setup_activity` is the module which implements the Setup activity, which is the activity to
-//! work on termscp configuration
-
 /**
  * MIT License
  *
- * termscp - Copyright (c) 2021 Christian Visintin
+ * termusic - Copyright (c) 2021 Larry Hao
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -312,6 +307,17 @@ impl TagEditorActivity {
                 }
                 TransferState::ErrDownload => {
                     self.mount_error("download failed");
+                    let props = label::LabelPropsBuilder::from(
+                        self.view.get_props(COMPONENT_TE_LABEL_HELP).unwrap(),
+                    )
+                    .with_background(Color::Reset)
+                    .with_foreground(Color::Cyan)
+                    .with_text(String::from("Press \"?\" for help."))
+                    .build();
+
+                    let msg = self.view.update(COMPONENT_TE_LABEL_HELP, props);
+                    self.update(msg);
+                    self.exit_reason = Some(ExitReason::NeedRefreshPlaylist);
                     self.redraw = true;
                 }
             }
